@@ -28,20 +28,24 @@ describe 'cloudkitty' do
           :control_exchange     => '<SERVICE DEFAULT>'
         )
         is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
-          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-          :heartbeat_rate              => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-          :amqp_durable_queues         => '<SERVICE DEFAULT>',
-          :kombu_compression           => '<SERVICE DEFAULT>',
-          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-          :kombu_ssl_version           => '<SERVICE DEFAULT>',
-          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
-          :rabbit_retry_interval       => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl                     => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold        => '<SERVICE DEFAULT>',
+          :heartbeat_rate                     => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread               => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay              => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy            => '<SERVICE DEFAULT>',
+          :amqp_durable_queues                => '<SERVICE DEFAULT>',
+          :kombu_compression                  => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs                 => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile                 => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile                  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version                  => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues                   => '<SERVICE DEFAULT>',
+          :rabbit_retry_interval              => '<SERVICE DEFAULT>',
+          :rabbit_quorum_queue                => '<SERVICE DEFAULT>',
+          :rabbit_quorum_delivery_limit       => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_length    => '<SERVICE DEFAULT>',
+          :rabbit_quorum_max_memory_bytes     => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
           :transport_url => '<SERVICE DEFAULT>',
@@ -86,10 +90,14 @@ describe 'cloudkitty' do
       let :params do
         {
           :rabbit_ha_queues                   => true,
-          :rabbit_heartbeat_timeout_threshold => '60',
-          :rabbit_heartbeat_rate              => '10',
+          :rabbit_heartbeat_timeout_threshold => 60,
+          :rabbit_heartbeat_rate              => 10,
           :rabbit_heartbeat_in_pthread        => true,
-          :kombu_reconnect_delay              => '5.0',
+          :rabbit_quorum_queue                => true,
+          :rabbit_quorum_delivery_limit       => 3,
+          :rabbit_quorum_max_memory_length    => 5,
+          :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :kombu_reconnect_delay              => 5.0,
           :amqp_durable_queues                => true,
           :kombu_compression                  => 'gzip',
           :package_ensure                     => '2012.1.1-15.el6',
@@ -100,8 +108,6 @@ describe 'cloudkitty' do
           :control_exchange                   => 'cloudkitty',
           :storage_backend                    => 'gnocchi',
           :storage_version                    => '1',
-          :auth_section                       => 'keystone_authtoken',
-          :keystone_version                   => '3',
         }
       end
 
@@ -112,13 +118,17 @@ describe 'cloudkitty' do
           :control_exchange     => 'cloudkitty'
         )
         is_expected.to contain_oslo__messaging__rabbit('cloudkitty_config').with(
-          :heartbeat_timeout_threshold => '60',
-          :heartbeat_rate              => '10',
-          :heartbeat_in_pthread        => true,
-          :kombu_reconnect_delay       => '5.0',
-          :amqp_durable_queues         => true,
-          :kombu_compression           => 'gzip',
-          :rabbit_ha_queues            => true,
+          :heartbeat_timeout_threshold        => 60,
+          :heartbeat_rate                     => 10,
+          :heartbeat_in_pthread               => true,
+          :kombu_reconnect_delay              => 5.0,
+          :amqp_durable_queues                => true,
+          :kombu_compression                  => 'gzip',
+          :rabbit_ha_queues                   => true,
+          :rabbit_quorum_queue                => true,
+          :rabbit_quorum_delivery_limit       => 3,
+          :rabbit_quorum_max_memory_length    => 5,
+          :rabbit_quorum_max_memory_bytes     => 1073741824,
         )
         is_expected.to contain_oslo__messaging__notifications('cloudkitty_config').with(
           :transport_url => '<SERVICE DEFAULT>',
@@ -130,8 +140,6 @@ describe 'cloudkitty' do
       it 'configures various things' do
         is_expected.to contain_cloudkitty_config('storage/backend').with_value('gnocchi')
         is_expected.to contain_cloudkitty_config('storage/version').with_value('1')
-        is_expected.to contain_cloudkitty_config('fetcher_keystone/auth_section').with_value('keystone_authtoken')
-        is_expected.to contain_cloudkitty_config('fetcher_keystone/keystone_version').with_value('3')
       end
 
     end
